==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/ExecutablePropertyArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgument;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.List;


public class ExecutablePropertyArgumentSetImpl extends InstanceSet<ExecutablePropertyArgumentSet,ExecutablePropertyArgument> implements ExecutablePropertyArgumentSet {

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( ExecutablePropertyArgument executablepropertyargument : this ) executablepropertyargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( ExecutablePropertyArgument executablepropertyargument : this ) executablepropertyargument.setPP_Id( ref_PP_Id );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( ExecutablePropertyArgument executablepropertyargument : this ) messageargumentset.add( executablepropertyargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public PropertyParameterSet R1023_is_represented_by_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( ExecutablePropertyArgument executablepropertyargument : this ) propertyparameterset.add( executablepropertyargument.R1023_is_represented_by_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public ExecutablePropertyArgument nullElement() {
        return ExecutablePropertyArgumentImpl.EMPTY_EXECUTABLEPROPERTYARGUMENT;
    }

    @Override
    public ExecutablePropertyArgumentSet emptySet() {
      return new ExecutablePropertyArgumentSetImpl();
    }

    @Override
    public ExecutablePropertyArgumentSet value() {
        return this;
    }

    @Override
    public List<ExecutablePropertyArgument> elements() {
        return Arrays.asList(toArray(new ExecutablePropertyArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/ExecutablePropertyArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgument;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ExecutablePropertyArgumentSetImpl extends InstanceSet<ExecutablePropertyArgumentSet,ExecutablePropertyArgument> implements ExecutablePropertyArgumentSet {

    public ExecutablePropertyArgumentSetImpl() {
    }

    public ExecutablePropertyArgumentSetImpl(Comparator<? super ExecutablePropertyArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( ExecutablePropertyArgument executablepropertyargument : this ) executablepropertyargument.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( ExecutablePropertyArgument executablepropertyargument : this ) executablepropertyargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( ExecutablePropertyArgument executablepropertyargument : this ) messageargumentset.add( executablepropertyargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public PropertyParameterSet R1023_is_represented_by_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( ExecutablePropertyArgument executablepropertyargument : this ) propertyparameterset.add( executablepropertyargument.R1023_is_represented_by_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public ExecutablePropertyArgument nullElement() {
        return ExecutablePropertyArgumentImpl.EMPTY_EXECUTABLEPROPERTYARGUMENT;
    }

    @Override
    public ExecutablePropertyArgumentSet emptySet() {
      return new ExecutablePropertyArgumentSetImpl();
    }

    @Override
    public ExecutablePropertyArgumentSet emptySet(Comparator<? super ExecutablePropertyArgument> comp) {
      return new ExecutablePropertyArgumentSetImpl(comp);
    }

    @Override
    public ExecutablePropertyArgumentSet value() {
        return this;
    }

    @Override
    public List<ExecutablePropertyArgument> elements() {
        return Arrays.asList(toArray(new ExecutablePropertyArgument[0]));
    }

}
